@@ -82,6 +82,7 @@ public void sym_algs2(unsigned int);
 public int  iv_len(unsigned int);
 public void comp_algs(unsigned int);
 public void hash_algs(unsigned int);
+public void aead_algs(unsigned int);
 public void key_id(void);
 public void fingerprint(void);
 public void time4(string);
@@ -138,6 +139,7 @@ public void revocable(int);
 public void key_expiration_time(int);
 public void additional_decryption_key(int);
 public void preferred_symmetric_algorithms(int);
+public void preferred_aead_algorithms(int);
 public void revocation_key(int);
 public void issuer_key_ID(int);
 public void notation_data(int);
